Plotting bandsdosplot — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

Note

Go to the end to download the full example code.

# Plotting bandsdosplot

Plotting bandsdosplot example.

First download the example files with the code below. Then replace data_dir below.

Downloading example

    bands_dir = pyprocar.download_example(save_dir='',
                                 material='Fe',
                                 code='vasp',
                                 spin_calc_type='non-spin-polarized',
                                 calc_type='bands')

    dos_dir = pyprocar.download_example(save_dir='',
                                 material='Fe',
                                 code='vasp',
                                 spin_calc_type='non-spin-polarized',
                                 calc_type='dos')

importing pyprocar and specifying local data_dir

    import os

    import pyprocar

    bands_dir = os.path.join(
        pyprocar.utils.DATA_DIR, "examples", "Fe", "vasp", "non-spin-polarized", "bands"
    )
    dos_dir = os.path.join(
        pyprocar.utils.DATA_DIR, "examples", "Fe", "vasp", "non-spin-polarized", "dos"
    )

## Plain mode

The keywords that works for bandsplot and dosplot will work in bandsdosplot. These keyword arguments can be set in bands_settings and dos_settings as done below.

    bands_settings = {
        "mode": "plain",
        "fermi": 5.599480,  # This will overide the default fermi value found in bands directory
        "dirname": bands_dir,
    }

    dos_settings = {
        "mode": "plain",
        "fermi": 5.599480,  # This will overide the default fermi value found in dos directory
        "dirname": dos_dir,
    }

    pyprocar.bandsdosplot(
        code="vasp",
        bands_settings=bands_settings,
        dos_settings=dos_settings,
    )

     ____        ____
    |  _ \ _   _|  _ \ _ __ ___   ___ __ _ _ __
    | |_) | | | | |_) | '__/ _ \ / __/ _` | '__|
    |  __/| |_| |  __/| | | (_) | (_| (_| | |
    |_|    \__, |_|   |_|  \___/ \___\__,_|_|
           |___/
    A Python library for electronic structure pre/post-processing.

    Version 6.3.2 created on Jun 10th, 2021

    Please cite:
     Uthpala Herath, Pedram Tavadze, Xu He, Eric Bousquet, Sobhit Singh, Francisco Muñoz and Aldo Romero.,
     PyProcar: A Python library for electronic structure pre/post-processing.,
     Computer Physics Communications 251 (2020):107080.

    Developers:
    - Francisco Muñoz
    - Aldo Romero
    - Sobhit Singh
    - Uthpala Herath
    - Pedram Tavadze
    - Eric Bousquet
    - Xu He
    - Reese Boucher
    - Logan Lang
    - Freddy Farah

                ----------------------------------------------------------------------------------------------------------
                There are additional plot options that are defined in the configuration file.
                You can change these configurations by passing the keyword argument to the function.
                To print a list of all plot options set `print_plot_opts=True`

                Here is a list modes : plain , parametric , scatter , atomic , overlay , overlay_species , overlay_orbitals
                ----------------------------------------------------------------------------------------------------------

                --------------------------------------------------------
                There are additional plot options that are defined in a configuration file.
                You can change these configurations by passing the keyword argument to the function
                To print a list of plot options set print_plot_opts=True

                Here is a list modes : plain , parametric , parameteric_line , stack , stack_orbitals , stack_species , overlay , overlay_orbitals , overlay_species
                --------------------------------------------------------

    (<Figure size 1650x550 with 2 Axes>, <Axes: xlabel='K vector', ylabel='E - E$_F$ (eV)'>, <Axes: xlabel='DOS'>)

Total running time of the script: (0 minutes 0.320 seconds)

Gallery generated by Sphinx-Gallery